Module getip::libc_getips [−][src]
Functions
Get all assigned ip addresses of the specified type on the specified interface Both parameters can be None, in which case that filter is not applied.
Get all assigned ip addresses of the specified type on the specified interface Both parameters can be None, in which case that filter is not applied.